==> flush-css-chunks-webpack-plugin-0.0.2.tgz: package/lib/flush-css-chunks-webpack-plugin.js <==
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var _require = require('webpack-sources'),
    ConcatSource = _require.ConcatSource;

var _require2 = require('webpack/lib/ModuleFilenameHelpers'),
    matchObject = _require2.matchObject;

function isInitial(chunk) {
  return chunk.isInitial() || chunk.parents.length === 0;
}

function generateAssetMapping(path, assets) {
  var mapping = {};
  var assetKeys = Object.keys(assets);

  assetKeys.forEach(function (assetKey) {
    if (Array.isArray(assets[assetKey])) {
      assets[assetKey].forEach(function (assetPath) {
        if (assetPath.includes('.css')) {
          Object.assign(mapping, { [assetKey]: `${path}${assetPath}` });
        }
      });
    }
  });

  return mapping;
}

function generateAssetsHook() {
  var mapping = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  return `
        if (typeof window === "object") {
            window.__CSS_CHUNKS__ = ${JSON.stringify(mapping)};
        }
    `.trim();
}

var FlushCSSChunks = function () {
  function FlushCSSChunks() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    _classCallCheck(this, FlushCSSChunks);

    this.options = Object.assign({
      entryOnly: false
    }, options);
  }

  _createClass(FlushCSSChunks, [{
    key: 'apply',
    value: function apply(compiler) {
      var _this = this;

      compiler.plugin('compilation', function (compilation) {
        compilation.plugin('optimize-chunk-assets', function (chunks, callback) {
          var publicPath = compiler.options.output.publicPath;

          var _compilation$getStats = compilation.getStats().toJson(),
              assetsByChunkName = _compilation$getStats.assetsByChunkName;

          var assetMapping = generateAssetsHook(generateAssetMapping(publicPath, assetsByChunkName));

          chunks.forEach(function (chunk) {
            if (_this.options.entryOnly && !isInitial(chunk)) {
              return;
            }

            chunk.files.filter(function (file) {
              return matchObject({ test: new RegExp(/^(.(.*.js))*$/) }, file);
            }).forEach(function (file) {
              return FlushCSSChunks.injectAssetsMapping(compilation, file, assetMapping);
            });
          });

          callback();
        });
      });
    }
  }], [{
    key: 'injectAssetsMapping',
    value: function injectAssetsMapping(compilation, file, assetMapping) {
      var newSource = new ConcatSource(assetMapping);

      newSource.add(compilation.assets[file]);

      return Object.assign(compilation.assets, { [file]: newSource });
    }
  }]);

  return FlushCSSChunks;
}();

module.exports = FlushCSSChunks;

==> flush-css-chunks-webpack-plugin-0.1.0.tgz: package/lib/flush-css-chunks-webpack-plugin.js <==
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var _require = require('webpack-sources'),
    ConcatSource = _require.ConcatSource;

var _require2 = require('webpack/lib/ModuleFilenameHelpers'),
    matchObject = _require2.matchObject;

function isInitial(chunk) {
  return chunk.isInitial() || chunk.parents.length === 0;
}

function generateAssetMapping(path, assets) {
  var mapping = {};
  var assetKeys = Object.keys(assets);

  assetKeys.forEach(function (assetKey) {
    if (Array.isArray(assets[assetKey])) {
      assets[assetKey].forEach(function (assetPath) {
        if (assetPath.includes('.css')) {
          Object.assign(mapping, { [assetKey]: `${path}${assetPath}` });
        }
      });
    }
  });

  return mapping;
}

function generateAssetsHook() {
  var mapping = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  return `
        if (typeof window === "object") {
            window.__CSS_CHUNKS__ = ${JSON.stringify(mapping)};
        }
    `.trim();
}

var FlushCSSChunks = function () {
  function FlushCSSChunks() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    _classCallCheck(this, FlushCSSChunks);

    this.options = Object.assign({
      entryOnly: false,
      assetPath: null
    }, options);
  }

  _createClass(FlushCSSChunks, [{
    key: 'apply',
    value: function apply(compiler) {
      var _this = this;

      compiler.plugin('compilation', function (compilation) {
        compilation.plugin('optimize-chunk-assets', function (chunks, callback) {
          var publicPath = compiler.options.output.publicPath;

          var _compilation$getStats = compilation.getStats().toJson(),
              assetsByChunkName = _compilation$getStats.assetsByChunkName;

          var assetMapping = generateAssetsHook(generateAssetMapping(_this.options.assetPath || publicPath, assetsByChunkName));

          chunks.forEach(function (chunk) {
            if (_this.options.entryOnly && !isInitial(chunk)) {
              return;
            }

            chunk.files.filter(function (file) {
              return matchObject({ test: new RegExp(/^(.(.*.js))*$/) }, file);
            }).forEach(function (file) {
              return FlushCSSChunks.injectAssetsMapping(compilation, file, assetMapping);
            });
          });

          callback();
        });
      });
    }
  }], [{
    key: 'injectAssetsMapping',
    value: function injectAssetsMapping(compilation, file, assetMapping) {
      var newSource = new ConcatSource(assetMapping);

      newSource.add(compilation.assets[file]);

      return Object.assign(compilation.assets, { [file]: newSource });
    }
  }]);

  return FlushCSSChunks;
}();

module.exports = FlushCSSChunks;
